Package: ore
Version: 1.6.0
Date: 2017-04-13
Title: An R Interface to the Onigmo Regular Expression Library
Author: Jon Clayden, based on Onigmo by K. Kosako and K. Takata
Maintainer: Jon Clayden <code@clayden.org>
Suggests: crayon, rex, testthat
Description: Provides an alternative to R's built-in functionality for handling
    regular expressions, based on the Onigmo library. Offers first-class
    compiled regex objects, partial matching and function-based substitutions,
    amongst other features.
Encoding: UTF-8
License: BSD_3_clause + file LICENCE
Collate: workspace.R file.R dict.R ore.R match.R es.R zzz.R
URL: https://github.com/jonclayden/ore
BugReports: https://github.com/jonclayden/ore/issues
RoxygenNote: 5.0.1
NeedsCompilation: yes
Packaged: 2017-04-13 15:34:23 UTC; jon
Repository: CRAN
Date/Publication: 2017-04-13 22:23:32 UTC
Built: R 3.4.1; x86_64-w64-mingw32; 2017-08-31 02:58:45 UTC; windows
Archs: x64
