Package: ore
Version: 1.7.4.1
Date: 2023-12-04
Title: An R Interface to the Onigmo Regular Expression Library
Author: Jon Clayden, based on Onigmo by K. Kosako and K. Takata
Maintainer: Jon Clayden <code@clayden.org>
Suggests: crayon, rex, tinytest, covr
Description: Provides an alternative to R's built-in functionality for handling
    regular expressions, based on the Onigmo library. Offers first-class
    compiled regex objects, partial matching and function-based substitutions,
    amongst other features.
Encoding: UTF-8
Biarch: true
License: BSD_3_clause + file LICENCE
Collate: workspace.R file.R dict.R ore.R match.R es.R zzz.R
URL: https://github.com/jonclayden/ore
BugReports: https://github.com/jonclayden/ore/issues
Roxygen: list(old_usage=TRUE)
RoxygenNote: 7.1.1
Built: R 4.4.0; x86_64-apple-darwin12.6.0; 2024-04-29 00:32:39 UTC; unix
