Package: ore
Version: 1.7.0
Date: 2021-10-11
Title: An R Interface to the Onigmo Regular Expression Library
Author: Jon Clayden, based on Onigmo by K. Kosako and K. Takata
Maintainer: Jon Clayden <code@clayden.org>
Suggests: crayon, rex, tinytest, covr
Description: Provides an alternative to R's built-in functionality for handling
    regular expressions, based on the Onigmo library. Offers first-class
    compiled regex objects, partial matching and function-based substitutions,
    amongst other features.
Encoding: UTF-8
LazyData: true
Biarch: true
License: BSD_3_clause + file LICENCE
Collate: workspace.R file.R dict.R ore.R match.R es.R zzz.R
URL: https://github.com/jonclayden/ore
BugReports: https://github.com/jonclayden/ore/issues
RoxygenNote: 7.1.1
NeedsCompilation: yes
Packaged: 2021-10-12 08:21:54 UTC; jon
Repository: CRAN
Date/Publication: 2021-10-12 10:00:02 UTC
Built: R 4.0.5; x86_64-w64-mingw32; 2021-10-12 17:39:11 UTC; windows
Archs: x64
