# Generated by roxygen2: do not edit by hand

S3method("[",orematch)
S3method("[",orematches)
S3method(groups,default)
S3method(groups,orearg)
S3method(groups,orematch)
S3method(groups,orematches)
S3method(matches,default)
S3method(matches,orematch)
S3method(matches,orematches)
S3method(print,ore)
S3method(print,orematch)
S3method(print,orematches)
export("%~%")
export("%~|%")
export("%~~%")
export(es)
export(groups)
export(is.ore)
export(is.orematch)
export(is_ore)
export(is_orematch)
export(matches)
export(ore)
export(ore.dict)
export(ore.escape)
export(ore.file)
export(ore.ismatch)
export(ore.lastmatch)
export(ore.match)
export(ore.repl)
export(ore.search)
export(ore.split)
export(ore.subst)
export(ore.switch)
export(ore_dict)
export(ore_escape)
export(ore_file)
export(ore_ismatch)
export(ore_lastmatch)
export(ore_match)
export(ore_repl)
export(ore_search)
export(ore_split)
export(ore_subst)
export(ore_switch)
useDynLib(ore, .registration = TRUE, .fixes = "C_")
